Struct Mat3
Source pub struct Mat3 {
pub cols: [Vec3; 3],
}
A 3x3 column-major matrix.
Creates a matrix from column vectors.
Extracts the upper-left 3x3 matrix from a Mat4.
Returns the element at row and column.
Returns the inverse matrix, if the matrix is invertible.
Returns the transpose matrix.
Multiplies this matrix by another matrix.
Multiplies this matrix by a vector.
Returns the matrix as a column-major array.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
The returned type after indexing.
Performs the indexing (
container[index]) operation.
Read more
Performs the mutable indexing (
container[index]) operation.
Read more
The resulting type after applying the * operator.
The resulting type after applying the * operator.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.