pub struct Ray3 {
pub origin: Vec3,
pub direction: Vec3,
}Expand description
A normalized 3D ray.
Fields
origin: Vec3Ray origin.
direction: Vec3Normalized ray direction.
Implementations
Sourceimpl Ray3
impl Ray3
Sourcepub fn intersect_aabb(self, aabb: Aabb) -> Option<f32>
pub fn intersect_aabb(self, aabb: Aabb) -> Option<f32>
Intersects this ray with an AABB and returns nearest non-negative t.
Sourcepub fn intersect_sphere(self, center: Vec3, radius: f32) -> Option<f32>
pub fn intersect_sphere(self, center: Vec3, radius: f32) -> Option<f32>
Intersects this ray with a sphere and returns nearest non-negative t.
Sourcepub fn intersect_bounding_sphere(self, sphere: Sphere) -> Option<f32>
pub fn intersect_bounding_sphere(self, sphere: Sphere) -> Option<f32>
Intersects this ray with a sphere and returns nearest non-negative t.