Plane

Struct Plane 

pub struct Plane {
    pub normal: Vec3,
    pub distance: f32,
}
A plane defined by a unit normal and signed distance from the origin.

Fields

normal: Vec3

Unit normal.

distance: f32

Signed distance term in normal.dot(point) + distance = 0.

Implementations

Source

impl Plane

pub fn new(normal: Vec3, distance: f32) -> Self

Creates a plane from a normal and signed distance.

pub fn from_normal_and_point(normal: Vec3, point: Vec3) -> Self

Creates a plane through a point with the given normal.

pub fn from_three_points(a: Vec3, b: Vec3, c: Vec3) -> Self

Creates a plane from three points.

pub fn signed_distance(self, point: Vec3) -> f32

Returns the signed distance from a point to the plane.

pub fn project_point(self, point: Vec3) -> Vec3

Projects a point onto the plane.

pub fn intersect_ray(self, ray: Ray3) -> Option<f32>

Intersects a ray with the plane and returns non-negative t.

pub fn intersect_line(self, a: Vec3, b: Vec3) -> Option<Vec3>

Intersects a finite line segment with the plane.